==> gozerbot_0.99.1.orig.tar.gz: gozerbot-0.99.1/gplugs/oneliner.py <==
# plugs/oneliner.py
#
#
#

""" uses the random lib """

__copyright__ = 'this file is in the public domain'
__revision__ = '$Id: oneliner.py 517 2006-12-21 05:00:00Z deck $'

from gozerbot.generic import handle_exception
from gozerbot.commands import cmnds
from gozerbot.examples import examples
from gozerbot.plughelp import plughelp
from gozerbot.tests import tests

import re, random

plughelp.add('oneliner', 'display a oneliner')

oneliners=["100,000 sperm and you were the fastest?",
	"42.7 percent of all statistics are made up on the spot.",
	"99 percent of lawyers give the rest a bad name.",
	"A bartender is just a pharmacist with a limited inventory.",
	"A clean desk is a sign of a cluttered desk drawer.",
	"A clear conscience is usually the sign of a bad memory.",
	"A closed mouth gathers no foot.",
	"A conclusion is the place where you got tired of thinking.",
	"A day without sunshine is like, night.",
	"A diplomat is someone who can tell you to go to hell in such a way that you will look forward to the trip.",
	"A flashlight is a case for holding dead batteries.",
	"All generalizations are false, including this one.",
	"All men are idiots, and I married their King.",
	"Always remember you're unique, just like everyone else.",
	"Always try to be modest and be proud of it!",
	"Anything worth taking seriously is worth making fun of.",
	"Artificial Intelligence usually beats real stupidity.",
	"Assassins do it from behind.",
	"Atheism is a non-prophet organization.",
	"Auntie Em, Hate you, hate Kansas, taking the dog. Dorothy.",
	"Be nice to your kids. They'll choose your nursing home.",
	"Beauty is in the eye of the beer holder.",
	"Beer: It's not just for breakfast anymore.",
	"Before you criticize someone, you should walk a mile in their shoes. That way, when you criticize them, you're a mile away and you have their shoes.",
	"Better to understand a little than to misunderstand a lot.",
	"Bills travel through the mail at twice the speed of checks",
	"Borrow money from a pessimist, they don't expect it back.",
	"Boycott shampoo! Demand the REAL poo!",
	"C program run. C program crash. C programmer quit.",
	"Change is inevitable, except from a vending machine.",
	"Chocolate: the OTHER major food group.",
	"Consciousness: That annoying time between naps.",
	"Corduroy pillows: They're making headlines!",
	"Could you drive any better if I shoved that cell phone up your ass?",
	"Criminal Lawyer is a redundancy.",
	"Daddy, why doesn't this magnet pick up this floppy disk?",
	"Death is hereditary.",
	"Despite the cost of living, have you noticed how popular it remains?",
	"Did anyone see my lost carrier?",
	"Diplomacy is the art of saying good doggie while looking for a bigger stick.",
	"Do not walk behind me, for I may not lead. Do not walk ahead of me, for I may not follow. Do not walk beside me, either. Just leave me alone.",
	"Don't be irreplaceable; if you can't be replaced, you can't be promoted.",
	"Don't drink and drive. You might hit a bump and spill your drink.",
	"Don't piss me off! I'm running out of places to hide the bodies.",
	"Don't take life too seriously, you won't get out alive.",
	"Double your drive space. Delete Windows!",
	"Duct tape is like the force, it has a light side and a dark side and it holds the universe together.",
	"Eagles may soar, but weasels don't get sucked into jet engines.",
	"Energizer Bunny arrested and charged with battery.",
	"Error, no keyboard. Press F1 to continue.",
	"Ever notice how fast Windows runs? Neither did I.",
	"Ever stop to think, and forget to start again?",
	"Everyone has a photographic memory. Some don't have film.",
	"Experience is something you don't get until just after you need it.",
	"Experience is what you get when you didn't get what you wanted.",
	"Few women admit their age. Few men act theirs.",
	"For every action there is an equal and opposite criticism.",
	"For Sale: Parachute. Only used once, never opened, small stain.",
	"Forget world peace. Visualize using your turn signal.",
	"Friends help you move. Real friends help you move bodies.",
	"Friends may come and go, but enemies tend to accumulate.",
	"Generally speaking, you aren't learning much when your mouth is moving.",
	"Genius does what it must, talent does what it can, and you had best do what you're told.",
	"Get a new car for your spouse; it'll be a great trade!",
	"Give a man a fish and he will eat for a day. Teach him how to fish, and he will sit in a boat and drink beer all day.",
	"Give me ambiguity or give me something else.",
	"Good judgment comes from bad experience and a lot of that comes from bad judgment.",
	"Hard work has a future payoff. Laziness pays off now.",
	"He who laughs last thinks slowest.",
	"Honk if you love peace and quiet.",
	"Honk if you want to see my finger.",
	"How do you tell when you run out of invisible ink?",
	"How does Teflon stick to the pan?",
	"How many of you believe in telekinesis? Raise my hand.",
	"I am not a vegetarian because I love animals. I am a vegetarian because I hate plants.",
	"I couldn't repair your brakes, so I made your horn louder.",
	"I didn't say it was your fault. I said I was going to blame you.",
	"I don't suffer from insanity. I enjoy every minute of it.",
	"I feel like I'm diagonally parked in a parallel universe.",
	"I get enough exercise just pushing my luck.",
	"I just got lost in thought. It was unfamiliar territory.",
	"I need someone really bad. Are you really bad?",
	"I poured Spot remover on my dog. Now he's gone.",
	"I took an IQ test and the results were negative.",
	"I tried sniffing Coke once, but the ice cubes got stuck in my nose.",
	"I used to be indecisive. Now I'm not sure.",
	"I used to have a handle on life, and then it broke.",
	"I used to have an open mind but my brains kept falling out.",
	"I won't rise to the occasion, but I'll slide over to it.",
	"I wouldn't be caught dead with a necrophiliac.",
	"I'm as confused as a baby in a topless bar.",
	"I'm not a complete idiot, some parts are missing!",
	"I'm writing a book. I've got the page numbers done.",
	"If at first you don't succeed, destroy all evidence that you tried.",
	"If at first you don't succeed, skydiving is not for you.",
	"If Barbie is so popular, why do you have to buy her friends?",
	"If ignorance is bliss, you must be orgasmic.",
	"If you can read this, I can slam on my brakes and sue you!",
	"If you can't convince them, confuse them.",
	"If you choke a smurf, what color does it turn?",
	"If you get to it and you can't do it, well there you jolly well are, aren't you.",
	"If you haven't much education you must use your brain.",
	"If you lend someone $20, and never see that person again; it was probably worth it.",
	"If you tell the truth you don't have to remember anything.",
	"If you think nobody cares if you're alive, try missing a couple of car payments.",
	"IRS: We've got what it takes to take what you've got.",
	"It IS as bad as you think, and they ARE out to get you.",
	"It is far more impressive when others discover your good qualities without your help.",
	"It may be that your sole purpose in life is simply to serve as a warning to others.",
	"It's always darkest before dawn. So if you're going to steal the neighbor's newspaper, that's the time to do it.",
	"It's lonely at the top, but you eat better.",
	"Jack Kevorkian for White House Physician.",
	"Jesus loves you, but everyone else thinks you're an asshole.",
	"Join the Army, meet interesting people, and kill them.",
	"Keep honking. I'm reloading.",
	"Laughing stock: cattle with a sense of humor.",
	"Learn from your parents' mistakes: use birth control.",
	"Lottery: A tax on people who are bad at math.",
	"Love may be blind but marriage is a real eye-opener.",
	"Make it idiot proof and someone will make a better idiot.",
	"Monday is an awful way to spend 1/7th of your life.",
	"Montana: At least our cows are sane!",
	"More hay, Trigger? No thanks, Roy, I'm stuffed!",
	"Multitasking means screwing up several things at once.",
	"My hockey mom can beat up your soccer mom.",
	"My mind is like a steel trap, rusty and illegal in 37 states.",
	"Never ask a barber if he thinks you need a haircut.",
	"Never do card tricks for the group you play poker with.",
	"Never mess up an apology with an excuse.",
	"Never miss a good chance to shut up.",
	"Never test the depth of the water with both feet.",
	"Never underestimate the power of stupid people in large groups.",
	"No one is listening until you make a mistake.",
	"Oh Lord, give me patience, and GIVE IT TO ME NOW!",
	"Okay, who put a stop payment on my reality check?",
	"On the other hand, you have different fingers.",
	"Oops. My brain just hit a bad sector.",
	"Out of my mind. Back in five minutes.",
	"Pentiums melt in your PC, not in your hand.",
	"Plan to be spontaneous, tomorrow.",
	"Pride is what we have. Vanity is what others have.",
	"Puritanism: The haunting fear that someone, somewhere may be happy.",
	"Quantum mechanics: The dreams stuff is made of.",
	"Quickly, I must hurry, for there go my people and I am their leader.",
	"Reality is a crutch for people who can't handle drugs.",
	"Remember half the people you know are below average.",
	"Save the whales. Collect the whole set",
	"Save your breath. You'll need it to blow up your date!",
	"Sex is like air; it's not important unless you aren't getting any.",
	"Shin: a device for finding furniture in the dark.",
	"Smile, it's the second best thing you can do with your lips.",
	"Smith & Wesson: The original point and click interface.",
	"Some days you are the bug, some days you are the windshield.",
	"Some drink at the fountain of knowledge. Others just gargle.",
	"Some people are only alive because it is illegal to shoot them.",
	"Success always occurs in private and failure in full view.",
	"Suicidal twin kills sister by mistake!",
	"Support bacteria, they're the only culture some people have.",
	"The Bermuda Triangle got tired of warm weather. It moved to Finland. Now Santa Claus is missing.",
	"The colder the x-ray table, the more of your body is required on it.",
	"The early bird may get the worm, but the second mouse gets the cheese.",
	"The hardness of butter is directly proportional to the softness of the bread.",
	"The journey of a thousand miles begins with a broken fan belt and a flat tire.",
	"The more you complain, the longer God makes you live.",
	"The only substitute for good manners is fast reflexes.",
	"The problem with the gene pool is that there is no lifeguard.",
	"The quickest way to double your money is to fold it in half and put it back in your pocket.",
	"The secret of the universe is @*&^^^ NO CARRIER",
	"The severity of the itch is inversely proportional to the ability to reach it.",
	"The sex was so good that even the neighbors had a cigarette.",
	"The shortest distance between two points is under construction.",
	"The sooner you fall behind the more time you'll have to catch up.",
	"The universe is a figment of its own imagination. There's no future in time travel.",
	"There are 3 kinds of people: those who can count & those who can't.",
	"There are two theories to arguing with women. Neither one works.",
	"There's too much blood in my caffeine system.",
	"Things are more like they are now than they ever were before.",
	"Time is the best teacher; unfortunately it kills all of its students.",
	"Time is what keeps everything from happening at once.",
	"Timing has an awful lot to do with the outcome of a rain dance.",
	"To steal ideas from one person is plagiarism; to steal from many is research.",
	"To succeed in politics, it is often necessary to rise above your principles.",
	"Very funny Scotty, now beam down my clothes.",
	"Wanted: Meaningful overnight relationship.",
	"Warning: Dates in calendar are closer than they appear.",
	"We have enough youth, how about a fountain of smart?",
	"We were born naked, wet and hungry. Then things got worse.",
	"Wear short sleeves! Support your right to bare arms!",
	"What happens if you get scared half to death twice?",
	"What is a free gift? Aren't all gifts free?",
	"What's the speed of dark?",
	"When everything's coming your way, you're in the wrong lane and going the wrong way.",
	"When there's a will, I want to be in it.",
	"When you don't know what you are doing, do it neatly.",
	"Who is General Failure and why is he reading my hard disk?",
	"Who stopped payment on my reality check?",
	"Why do psychics have to ask you for your name?",
	"Why is abbreviation such a long word?",
	"Why isn't phonetic spelled the way it sounds?",
	"Women who seek to be equal to men lack ambition.",
	"You are depriving some poor village of its idiot.",
	"You can do more with a kind word and a gun than with just a kind word.",
	"You have the right to remain silent. Anything you say will be misquoted then used against you.",
	"You're just jealous because the voices are talking to me and not you!",
	"Your gene pool could use a little chlorine.",
	"Your kid may be an honors student, but you're still an idiot."]

def handle_oneliner(bot, ievent):
    data = oneliners[random.randint(0,len(oneliners)-1)]
    ievent.reply(data)

cmnds.add('oneliner', handle_oneliner, 'USER')
examples.add('oneliner', 'show oneliner', 'oneliner')
tests.add('oneliner')

==> gozerbot-1.0.3.tar.gz: gozerbot-1.0.3/gplugs/oneliner.py <==
# plugs/oneliner.py
#
#

""" do a oneliner .. uses the random lib """

__revision__ = '$Id: oneliner.py 517 2006-12-21 05:00:00Z deck $'
__status__ = "seen"

## gozerbot imports

from gozerbot.generic import handle_exception
from gozerbot.commands import cmnds
from gozerbot.examples import examples
from gozerbot.plughelp import plughelp
from gozerbot.tests import tests

## basic imports

import re
import random

# plughelp

plughelp.add('oneliner', 'display a oneliner')

# defines

oneliners=["100,000 sperm and you were the fastest?",
	"42.7 percent of all statistics are made up on the spot.",
	"99 percent of lawyers give the rest a bad name.",
	"A bartender is just a pharmacist with a limited inventory.",
	"A clean desk is a sign of a cluttered desk drawer.",
	"A clear conscience is usually the sign of a bad memory.",
	"A closed mouth gathers no foot.",
	"A conclusion is the place where you got tired of thinking.",
	"A day without sunshine is like, night.",
	"A diplomat is someone who can tell you to go to hell in such a way that you will look forward to the trip.",
	"A flashlight is a case for holding dead batteries.",
	"All generalizations are false, including this one.",
	"All men are idiots, and I married their King.",
	"Always remember you're unique, just like everyone else.",
	"Always try to be modest and be proud of it!",
	"Anything worth taking seriously is worth making fun of.",
	"Artificial Intelligence usually beats real stupidity.",
	"Assassins do it from behind.",
	"Atheism is a non-prophet organization.",
	"Auntie Em, Hate you, hate Kansas, taking the dog. Dorothy.",
	"Be nice to your kids. They'll choose your nursing home.",
	"Beauty is in the eye of the beer holder.",
	"Beer: It's not just for breakfast anymore.",
	"Before you criticize someone, you should walk a mile in their shoes. That way, when you criticize them, you're a mile away and you have their shoes.",
	"Better to understand a little than to misunderstand a lot.",
	"Bills travel through the mail at twice the speed of checks",
	"Borrow money from a pessimist, they don't expect it back.",
	"Boycott shampoo! Demand the REAL poo!",
	"C program run. C program crash. C programmer quit.",
	"Change is inevitable, except from a vending machine.",
	"Chocolate: the OTHER major food group.",
	"Consciousness: That annoying time between naps.",
	"Corduroy pillows: They're making headlines!",
	"Could you drive any better if I shoved that cell phone up your ass?",
	"Criminal Lawyer is a redundancy.",
	"Daddy, why doesn't this magnet pick up this floppy disk?",
	"Death is hereditary.",
	"Despite the cost of living, have you noticed how popular it remains?",
	"Did anyone see my lost carrier?",
	"Diplomacy is the art of saying good doggie while looking for a bigger stick.",
	"Do not walk behind me, for I may not lead. Do not walk ahead of me, for I may not follow. Do not walk beside me, either. Just leave me alone.",
	"Don't be irreplaceable; if you can't be replaced, you can't be promoted.",
	"Don't drink and drive. You might hit a bump and spill your drink.",
	"Don't piss me off! I'm running out of places to hide the bodies.",
	"Don't take life too seriously, you won't get out alive.",
	"Double your drive space. Delete Windows!",
	"Duct tape is like the force, it has a light side and a dark side and it holds the universe together.",
	"Eagles may soar, but weasels don't get sucked into jet engines.",
	"Energizer Bunny arrested and charged with battery.",
	"Error, no keyboard. Press F1 to continue.",
	"Ever notice how fast Windows runs? Neither did I.",
	"Ever stop to think, and forget to start again?",
	"Everyone has a photographic memory. Some don't have film.",
	"Experience is something you don't get until just after you need it.",
	"Experience is what you get when you didn't get what you wanted.",
	"Few women admit their age. Few men act theirs.",
	"For every action there is an equal and opposite criticism.",
	"For Sale: Parachute. Only used once, never opened, small stain.",
	"Forget world peace. Visualize using your turn signal.",
	"Friends help you move. Real friends help you move bodies.",
	"Friends may come and go, but enemies tend to accumulate.",
	"Generally speaking, you aren't learning much when your mouth is moving.",
	"Genius does what it must, talent does what it can, and you had best do what you're told.",
	"Get a new car for your spouse; it'll be a great trade!",
	"Give a man a fish and he will eat for a day. Teach him how to fish, and he will sit in a boat and drink beer all day.",
	"Give me ambiguity or give me something else.",
	"Good judgment comes from bad experience and a lot of that comes from bad judgment.",
	"Hard work has a future payoff. Laziness pays off now.",
	"He who laughs last thinks slowest.",
	"Honk if you love peace and quiet.",
	"Honk if you want to see my finger.",
	"How do you tell when you run out of invisible ink?",
	"How does Teflon stick to the pan?",
	"How many of you believe in telekinesis? Raise my hand.",
	"I am not a vegetarian because I love animals. I am a vegetarian because I hate plants.",
	"I couldn't repair your brakes, so I made your horn louder.",
	"I didn't say it was your fault. I said I was going to blame you.",
	"I don't suffer from insanity. I enjoy every minute of it.",
	"I feel like I'm diagonally parked in a parallel universe.",
	"I get enough exercise just pushing my luck.",
	"I just got lost in thought. It was unfamiliar territory.",
	"I need someone really bad. Are you really bad?",
	"I poured Spot remover on my dog. Now he's gone.",
	"I took an IQ test and the results were negative.",
	"I tried sniffing Coke once, but the ice cubes got stuck in my nose.",
	"I used to be indecisive. Now I'm not sure.",
	"I used to have a handle on life, and then it broke.",
	"I used to have an open mind but my brains kept falling out.",
	"I won't rise to the occasion, but I'll slide over to it.",
	"I wouldn't be caught dead with a necrophiliac.",
	"I'm as confused as a baby in a topless bar.",
	"I'm not a complete idiot, some parts are missing!",
	"I'm writing a book. I've got the page numbers done.",
	"If at first you don't succeed, destroy all evidence that you tried.",
	"If at first you don't succeed, skydiving is not for you.",
	"If Barbie is so popular, why do you have to buy her friends?",
	"If ignorance is bliss, you must be orgasmic.",
	"If you can read this, I can slam on my brakes and sue you!",
	"If you can't convince them, confuse them.",
	"If you choke a smurf, what color does it turn?",
	"If you get to it and you can't do it, well there you jolly well are, aren't you.",
	"If you haven't much education you must use your brain.",
	"If you lend someone $20, and never see that person again; it was probably worth it.",
	"If you tell the truth you don't have to remember anything.",
	"If you think nobody cares if you're alive, try missing a couple of car payments.",
	"IRS: We've got what it takes to take what you've got.",
	"It IS as bad as you think, and they ARE out to get you.",
	"It is far more impressive when others discover your good qualities without your help.",
	"It may be that your sole purpose in life is simply to serve as a warning to others.",
	"It's always darkest before dawn. So if you're going to steal the neighbor's newspaper, that's the time to do it.",
	"It's lonely at the top, but you eat better.",
	"Jack Kevorkian for White House Physician.",
	"Jesus loves you, but everyone else thinks you're an asshole.",
	"Join the Army, meet interesting people, and kill them.",
	"Keep honking. I'm reloading.",
	"Laughing stock: cattle with a sense of humor.",
	"Learn from your parents' mistakes: use birth control.",
	"Lottery: A tax on people who are bad at math.",
	"Love may be blind but marriage is a real eye-opener.",
	"Make it idiot proof and someone will make a better idiot.",
	"Monday is an awful way to spend 1/7th of your life.",
	"Montana: At least our cows are sane!",
	"More hay, Trigger? No thanks, Roy, I'm stuffed!",
	"Multitasking means screwing up several things at once.",
	"My hockey mom can beat up your soccer mom.",
	"My mind is like a steel trap, rusty and illegal in 37 states.",
	"Never ask a barber if he thinks you need a haircut.",
	"Never do card tricks for the group you play poker with.",
	"Never mess up an apology with an excuse.",
	"Never miss a good chance to shut up.",
	"Never test the depth of the water with both feet.",
	"Never underestimate the power of stupid people in large groups.",
	"No one is listening until you make a mistake.",
	"Oh Lord, give me patience, and GIVE IT TO ME NOW!",
	"Okay, who put a stop payment on my reality check?",
	"On the other hand, you have different fingers.",
	"Oops. My brain just hit a bad sector.",
	"Out of my mind. Back in five minutes.",
	"Pentiums melt in your PC, not in your hand.",
	"Plan to be spontaneous, tomorrow.",
	"Pride is what we have. Vanity is what others have.",
	"Puritanism: The haunting fear that someone, somewhere may be happy.",
	"Quantum mechanics: The dreams stuff is made of.",
	"Quickly, I must hurry, for there go my people and I am their leader.",
	"Reality is a crutch for people who can't handle drugs.",
	"Remember half the people you know are below average.",
	"Save the whales. Collect the whole set",
	"Save your breath. You'll need it to blow up your date!",
	"Sex is like air; it's not important unless you aren't getting any.",
	"Shin: a device for finding furniture in the dark.",
	"Smile, it's the second best thing you can do with your lips.",
	"Smith & Wesson: The original point and click interface.",
	"Some days you are the bug, some days you are the windshield.",
	"Some drink at the fountain of knowledge. Others just gargle.",
	"Some people are only alive because it is illegal to shoot them.",
	"Success always occurs in private and failure in full view.",
	"Suicidal twin kills sister by mistake!",
	"Support bacteria, they're the only culture some people have.",
	"The Bermuda Triangle got tired of warm weather. It moved to Finland. Now Santa Claus is missing.",
	"The colder the x-ray table, the more of your body is required on it.",
	"The early bird may get the worm, but the second mouse gets the cheese.",
	"The hardness of butter is directly proportional to the softness of the bread.",
	"The journey of a thousand miles begins with a broken fan belt and a flat tire.",
	"The more you complain, the longer God makes you live.",
	"The only substitute for good manners is fast reflexes.",
	"The problem with the gene pool is that there is no lifeguard.",
	"The quickest way to double your money is to fold it in half and put it back in your pocket.",
	"The secret of the universe is @*&^^^ NO CARRIER",
	"The severity of the itch is inversely proportional to the ability to reach it.",
	"The sex was so good that even the neighbors had a cigarette.",
	"The shortest distance between two points is under construction.",
	"The sooner you fall behind the more time you'll have to catch up.",
	"The universe is a figment of its own imagination. There's no future in time travel.",
	"There are 3 kinds of people: those who can count & those who can't.",
	"There are two theories to arguing with women. Neither one works.",
	"There's too much blood in my caffeine system.",
	"Things are more like they are now than they ever were before.",
	"Time is the best teacher; unfortunately it kills all of its students.",
	"Time is what keeps everything from happening at once.",
	"Timing has an awful lot to do with the outcome of a rain dance.",
	"To steal ideas from one person is plagiarism; to steal from many is research.",
	"To succeed in politics, it is often necessary to rise above your principles.",
	"Very funny Scotty, now beam down my clothes.",
	"Wanted: Meaningful overnight relationship.",
	"Warning: Dates in calendar are closer than they appear.",
	"We have enough youth, how about a fountain of smart?",
	"We were born naked, wet and hungry. Then things got worse.",
	"Wear short sleeves! Support your right to bare arms!",
	"What happens if you get scared half to death twice?",
	"What is a free gift? Aren't all gifts free?",
	"What's the speed of dark?",
	"When everything's coming your way, you're in the wrong lane and going the wrong way.",
	"When there's a will, I want to be in it.",
	"When you don't know what you are doing, do it neatly.",
	"Who is General Failure and why is he reading my hard disk?",
	"Who stopped payment on my reality check?",
	"Why do psychics have to ask you for your name?",
	"Why is abbreviation such a long word?",
	"Why isn't phonetic spelled the way it sounds?",
	"Women who seek to be equal to men lack ambition.",
	"You are depriving some poor village of its idiot.",
	"You can do more with a kind word and a gun than with just a kind word.",
	"You have the right to remain silent. Anything you say will be misquoted then used against you.",
	"You're just jealous because the voices are talking to me and not you!",
	"Your gene pool could use a little chlorine.",
	"Your kid may be an honors student, but you're still an idiot."]

## oneliner command

def handle_oneliner(bot, ievent):
    data = oneliners[random.randint(0,len(oneliners)-1)]
    ievent.reply(data)

cmnds.add('oneliner', handle_oneliner, 'USER')
examples.add('oneliner', 'show oneliner', 'oneliner')
tests.add('oneliner')

#### BHJTW 23-01-2012
